Index: wp-includes/class-wp-query.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-includes/class-wp-query.php	(revision 220c0589da3b2bc1388dec16e892f3e1c7d213bc)
+++ wp-includes/class-wp-query.php	(revision )
@@ -665,7 +665,7 @@
 	 *     @type bool         $exact                   Whether to search by exact keyword. Default false.
 	 *     @type string|array $fields                  Which fields to return. Single field or all fields (string),
 	 *                                                 or array of fields. 'id=>parent' uses 'id' and 'post_parent'.
 	 *                                                 Default all fields. Accepts 'ids', 'id=>parent'.
 	 *     @type int          $hour                    Hour of the day. Default empty. Accepts numbers 0-23.
 	 *     @type int|bool     $ignore_sticky_posts     Whether to ignore sticky posts or not. Setting this to false
 	 *                                                 excludes stickies from 'post__in'. Accepts 1|true, 0|false.
@@ -1792,6 +1792,9 @@
 			case 'id=>parent':
 				$fields = "{$wpdb->posts}.ID, {$wpdb->posts}.post_parent";
 				break;
+			case 'id=>title':
+				$fields = "{$wpdb->posts}.ID, {$wpdb->posts}.post_title";
+				break;
 			default:
 				$fields = "{$wpdb->posts}.*";
 		}
@@ -2783,6 +2786,25 @@
 				$this->posts[ $key ]->post_parent = (int) $post->post_parent;
 
 				$r[ (int) $post->ID ] = (int) $post->post_parent;
+			}
+
+			return $r;
+		}
+
+		if ( 'id=>title' == $q['fields'] ) {
+			if ( null === $this->posts ) {
+				$this->posts = $wpdb->get_results( $this->request );
+			}
+
+			$this->post_count = count( $this->posts );
+			$this->set_found_posts( $q, $limits );
+
+			$r = array();
+			foreach ( $this->posts as $key => $post ) {
+				$this->posts[ $key ]->ID = (int) $post->ID;
+				$this->posts[ $key ]->post_title = $post->post_title;
+
+				$r[ (int) $post->ID ] = $post->post_title;
 			}
 
 			return $r;
@@ -665,7 +665,7 @@
 	 *     @type string|array $fields                  Which fields to return. Single field or all fields (string),
 	 *                                                 or array of fields. 'id=>parent' uses 'id' and 'post_parent'.
-	 *                                                 Default all fields. Accepts 'ids', 'id=>parent'.
+	 *                                                 Default all fields. Accepts 'ids', 'id=>parent', 'id=>title'.
 	 *     @type int          $hour                    Hour of the day. Default empty. Accepts numbers 0-23.
 	 *     @type int|bool     $ignore_sticky_posts     Whether to ignore sticky posts or not. Setting this to false
